@@ -26,7 +26,7 @@ class ConfigReader:
         self.content = content
 
     @staticmethod
-    def _load(format: "FormatLiteral", content: str) -> dict[str, t.Any]:
+    def _load(fmt: "FormatLiteral", content: str) -> dict[str, t.Any]:
         """Load raw config data and directly return it.
 
         >>> ConfigReader._load("json", '{ "session_name": "my session" }')
@@ -35,7 +35,7 @@ class ConfigReader:
         >>> ConfigReader._load("yaml", 'session_name: my session')
         {'session_name': 'my session'}
         """
-        if format == "yaml":
+        if fmt == "yaml":
             return t.cast(
                 dict[str, t.Any],
                 yaml.load(
@@ -43,13 +43,13 @@ class ConfigReader:
                     Loader=yaml.SafeLoader,
                 ),
             )
-        elif format == "json":
+        if fmt == "json":
             return t.cast(dict[str, t.Any], json.loads(content))
-        else:
-            raise NotImplementedError(f"{format} not supported in configuration")
+        msg = f"{fmt} not supported in configuration"
+        raise NotImplementedError(msg)
 
     @classmethod
-    def load(cls, format: "FormatLiteral", content: str) -> "ConfigReader":
+    def load(cls, fmt: "FormatLiteral", content: str) -> "ConfigReader":
         """Load raw config data into a ConfigReader instance (to dump later).
 
         >>> cfg = ConfigReader.load("json", '{ "session_name": "my session" }')
@@ -66,7 +66,7 @@ class ConfigReader:
         """
         return cls(
             content=cls._load(
-                format=format,
+                fmt=fmt,
                 content=content,
             ),
         )
@@ -104,15 +104,16 @@ class ConfigReader:
         assert isinstance(path, pathlib.Path)
         content = path.open().read()
 
-        if path.suffix in [".yaml", ".yml"]:
-            format: "FormatLiteral" = "yaml"
+        if path.suffix in {".yaml", ".yml"}:
+            fmt: "FormatLiteral" = "yaml"
         elif path.suffix == ".json":
-            format = "json"
+            fmt = "json"
         else:
-            raise NotImplementedError(f"{path.suffix} not supported in {path}")
+            msg = f"{path.suffix} not supported in {path}"
+            raise NotImplementedError(msg)
 
         return cls._load(
-            format=format,
+            fmt=fmt,
             content=content,
         )
 
@@ -158,7 +159,7 @@ class ConfigReader:
 
     @staticmethod
     def _dump(
-        format: "FormatLiteral",
+        fmt: "FormatLiteral",
         content: "RawConfigData",
         indent: int = 2,
         **kwargs: t.Any,
@@ -171,22 +172,22 @@ class ConfigReader:
         >>> ConfigReader._dump("json", { "session_name": "my session" })
         '{\n  "session_name": "my session"\n}'
         """
-        if format == "yaml":
+        if fmt == "yaml":
             return yaml.dump(
                 content,
                 indent=2,
                 default_flow_style=False,
                 Dumper=yaml.SafeDumper,
             )
-        elif format == "json":
+        if fmt == "json":
             return json.dumps(
                 content,
                 indent=2,
             )
-        else:
-            raise NotImplementedError(f"{format} not supported in config")
+        msg = f"{fmt} not supported in config"
+        raise NotImplementedError(msg)
 
-    def dump(self, format: "FormatLiteral", indent: int = 2, **kwargs: t.Any) -> str:
+    def dump(self, fmt: "FormatLiteral", indent: int = 2, **kwargs: t.Any) -> str:
         r"""Dump via ConfigReader instance.
 
         >>> cfg = ConfigReader({ "session_name": "my session" })
@@ -196,7 +197,7 @@ class ConfigReader:
         '{\n  "session_name": "my session"\n}'
         """
         return self._dump(
-            format=format,
+            fmt=fmt,
             content=self.content,
             indent=indent,
             **kwargs,
